// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KMBOX_VERSION_H
#define KMBOX_VERSION_H

#define KMBOX_VERSION_STRING "6.5.2"
#define KMBOX_VERSION_MAJOR 6
#define KMBOX_VERSION_MINOR 5
#define KMBOX_VERSION_PATCH 2
#define KMBOX_VERSION ((6<<16)|(5<<8)|(2))

#endif
